pub struct ViewBasedUpgrade {
pub start_proposing_view: u64,
pub stop_proposing_view: u64,
pub start_voting_view: Option<u64>,
pub stop_voting_view: Option<u64>,
}Expand description
Represents an upgrade based on view.
Fields
start_proposing_view: u64the earliest view in which the node can propose an upgrade
stop_proposing_view: u64view after which the node stops proposing an upgrade
start_voting_view: Option<u64>The view at which voting for the upgrade proposal starts
stop_voting_view: Option<u64>The view at which voting for the upgrade proposal stops